@@ -131,6 +131,7 @@ def opa_binary():
                 pass
             else:
                 opa_exe = None
+
     return opa_exe
 
 
@@ -266,9 +267,14 @@ class ComparatorV01:
                 open(rego_file, 'w').write('\n'.join(rego_txt))
             if rego_file:
                 if isinstance(rule_expr, list):
-                    os.system('%s eval -i /tmp/input.json -d %s "data.rule" > /tmp/a.json' % (opa_exe, rego_file))
+                    result = os.system('%s eval -i /tmp/input.json -d %s "data.rule" > /tmp/a.json' % (opa_exe, rego_file))
+                    if result != 0 :
+                         logger.info("\t\tERROR: have problem in running opa binary")
                 else:
-                    os.system('%s eval -i /tmp/input.json -d %s "%s" > /tmp/a.json' % (opa_exe, rego_file, rule_expr))
+                    result = os.system('%s eval -i /tmp/input.json -d %s "%s" > /tmp/a.json' % (opa_exe, rego_file, rule_expr))
+                    if result != 0 :
+                        logger.info("\t\tERROR: have problem in running opa binary")
+
                 resultval = json_from_file('/tmp/a.json')
                 if resultval and "errors" in resultval and resultval["errors"]:
                     results.append({'eval': rule_expr, 'result': "passed" if result else "failed", 'message': ''})
